#ifndef AC_MODEL_H
#define AC_MODEL_H

#include "../interfaces/libpq/libpq-fe.h"

#include "catalog/pg_class.h"
#include "catalog/pg_database.h"
#include "catalog/pg_namespace.h"
#include "catalog/pg_tablespace.h"
#include "catalog/pg_largeobject.h"

/* rbt: тип модели защиты сервера */
typedef enum
{
	AC_MODEL_NONE,
	AC_MODEL_SE,
	AC_MODEL_DP0,
	AC_MODEL_DP1,
	AC_MODEL_DP2
} ACModelVersion;

/* Текущая модель защиты сервера */
extern ACModelVersion acmodel;

#define MAXLEN 32
#define AC_MODEL_SETTING "ac_model_version"

#define AC_MODEL_GE(model) (acmodel >= (model))
#define AC_MODEL_EQ(model) (acmodel == (model))
#define NO_AC_MODEL (acmodel == AC_MODEL_NONE)

/* Определить модель защиты сервера */
void DetermineModelVersion(PGconn *connection);

/* Распечатать версию модели сервера в лог */
void PrintACModel(const char *prog, const bool verbose);

/* Получить значение использования метки на столбцах */
bool GetRelationUseColumnMacs(PGconn *connection, const Oid oid);

/* Получение значения использования меток на строках */
bool GetRelationUseRowMacs(PGconn *connection, const Oid oid);

/* Получить значение MAC CCR отношения */
bool GetRelationMACCCR(PGconn *connection, const Oid oid);

/* Получить мандатную метку отношения */
char *GetRelationMaclabel(PGconn *connection, const Oid oid);

#endif /* AC_MODEL_H */
