/*-------------------------------------------------------------------------
 *
 * gost.h
 *	  Interface to libpq/gost.c
 *
 * These definitions are needed by both frontend and backend code to work
 * with Gost2012-encrypted passwords.
 *
 * Rusbitech Copyright (c) 2016
 *
 * src/include/libpq/gost.h
 *
 *-------------------------------------------------------------------------
 */
#ifndef PG_GOST_H
#define PG_GOST_H

#include "c.h"
#include <gost/gostcrypt.h>

#define GOST_PREFIX			"gost12512hash"
#define GOST_SIZE			64
#define GOST_HASH_LEN		((GOST_SIZE) * 2) /* 128 */
#define GOST_PASSWD_LEN		(strlen(GOST_PREFIX) + GOST_HASH_LEN)

#define isGOST(passwd)		(strncmp(passwd, GOST_PREFIX, strlen(GOST_PREFIX)) == 0 && \
							 strlen(passwd) == GOST_PASSWD_LEN)

extern bool pg_gost_hash(const void *buff, size_t len, char *hexsum);
extern bool pg_gost_binary(const void *buff, size_t len, void *outbuf);
extern bool pg_gost_encrypt(const char *passwd, const char *salt,
							size_t salt_len, char *buf);

#endif
