/*-------------------------------------------------------------------------
 *
 * pgac_memwipe.h
 *	  Заголовочный файл для функций очистки памяти
 *
 *
 * Copyright (c) 2016 Rusbitech
 *
 * src/include/utils/pgac_memwipe.h
 *
 *-------------------------------------------------------------------------
 */
#ifndef PGAC_MEMWIPE_H
#define PGAC_MEMWIPE_H

#include "postgres.h"
#include "guc.h"
#include "storage/bufpage.h"
#include "storage/fd.h"
#include "postmaster/bgwriter.h"
#include "utils/pgac_mac.h"

/* GUC переменные */
extern bool pgac_memwipe_buffers;
extern bool pgac_memwipe_pages;
extern bool pgac_memwipe_files;

void _pgmw_wipeBuffer(const int buffer_id);
void _pgmw_wipePage(Page page, const Offset pd_upper_old, const Offset pd_upper_new);
void _pgmw_wipeFile(const File fd, const Offset offset);
void _pgmw_fileFilePath(const char *file_path, Offset offset);

#define pgmw_wipeBuffer(_fd) \
do { \
	if (pgac_memwipe_buffers) \
		_pgmw_wipeBuffer(_fd); \
} while(0)

#define pgmw_wipePage(_page, _pd_lower_old, _pd_upper_new) \
do { \
	if (pgac_memwipe_pages) \
		_pgmw_wipePage(_page, _pd_lower_old, _pd_upper_new); \
} while(0)

#define pgmw_wipeFile(_fd, _offset) \
do { \
	if (pgac_memwipe_files) \
		_pgmw_wipeFile(_fd, _offset); \
} while(0)

#define pgmw_wipeFilePath(_file_path, _offset) \
do { \
	if (pgac_memwipe_files) \
		_pgmw_fileFilePath(_file_path, _offset); \
} while(0)

#define pgmw_checkPoint() \
do { \
	if (pgac_memwipe_pages | pgac_memwipe_files) \
		RequestCheckpoint(CHECKPOINT_IMMEDIATE | CHECKPOINT_FORCE | CHECKPOINT_WAIT \
						  | CHECKPOINT_FLUSH_ALL); \
} while(0)

#endif
